summaryrefslogtreecommitdiff
path: root/framework/Web/UI/WebControls/TStyle.php
diff options
context:
space:
mode:
Diffstat (limited to 'framework/Web/UI/WebControls/TStyle.php')
-rw-r--r--framework/Web/UI/WebControls/TStyle.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/framework/Web/UI/WebControls/TStyle.php b/framework/Web/UI/WebControls/TStyle.php
index c6163367..6bc413e4 100644
--- a/framework/Web/UI/WebControls/TStyle.php
+++ b/framework/Web/UI/WebControls/TStyle.php
@@ -681,12 +681,12 @@ class TTableItemStyle extends TStyle
/**
* Sets the vertical alignment of the contents within the table item.
* Valid values include 'NotSet','Top','Bottom','Middel'
* @param string the horizontal alignment
*/
public function setVerticalAlign($value)
{
- $this->_verticalAlign=TPropertyValue::ensureEnum($value,array('NotSet','Top','Bottom','Middel'));
+ $this->_verticalAlign=TPropertyValue::ensureEnum($value,array('NotSet','Top','Bottom','Middle'));
}
/**
@@ -681,12 +681,12 @@ class TTableItemStyle extends TStyle
/**
* Sets the vertical alignment of the contents within the table item.
- * Valid values include 'NotSet','Top','Bottom','Middel'
+ * Valid values include 'NotSet','Top','Bottom','Middle'
* @param string the horizontal alignment
*/